@@ -1,8 +1,9 @@
-from .__core__ import PyotCore
-from pyot.utils import tft_url
-from pyot.core.exceptions import NotFound
 from typing import List, Iterator
 
+from pyot.utils import tft_url
+from pyot.core.functional import cache_indexes, lazy_property
+from .__core__ import PyotCore
+
 
 class ProfileIcon(PyotCore):
     id: int
@@ -14,26 +15,23 @@ class ProfileIcon(PyotCore):
     def __init__(self, id: int = None, locale: str = None):
         self._lazy_set(locals())
 
-    def _filter(self, data):
-        for item in data:
-            if item["id"] == self.id:
-                return item
-        raise NotFound
-    
-    def _refactor(self):
+    @cache_indexes
+    def _filter(self, indexer, data):
+        return indexer.get(self.id, data, "id")
+
+    def _clean(self):
         if self.locale.lower() == "en_us":
             self._meta.server = "default"
-        load = getattr(self._meta, "load")
-        self._meta.filter_key = str(load.pop("id"))
+        self._hide_load_value("id")
 
-    def _transform(self, data):
-        data["iconPath"] = tft_url(data["iconPath"])
-        return data
+    @lazy_property
+    def icon_abspath(self) -> str:
+        return tft_url(self.icon_path)
 
 
 class ProfileIcons(PyotCore):
     icons: List[ProfileIcon]
-    
+
     class Meta(PyotCore.Meta):
         rules = {"cdragon_profile_icon_full": []}
 
@@ -51,7 +49,7 @@ class ProfileIcons(PyotCore):
     def __len__(self):
         return len(self.icons)
 
-    def _refactor(self):
+    def _clean(self):
         if self.locale.lower() == "en_us":
             self._meta.server = "default"
 
