@@ -1,4 +1,4 @@
-from datetime import datetime, timedelta
+from datetime import datetime
 import asyncio
 
 from .common import loop_run
